@@ -86,15 +86,20 @@ class SubscriptionRequestFromPartnerForm:
             "birthdate": self.partner_data.get("birth_date").strftime("%Y-%m-%d"),
             "gender": self.partner_data.get("sex"),
             "is_company": self._is_company(),
-            "company_name": self.partner_data.get("tradename"),
-            # TODO: Lastname, Tradename, Phone???
+            "company_name": self._get_company_name(),
             "voluntary_contribution": int(
                 self.partner_data.get("contribute_somconnexio_option")
             ),
         }
 
+    def _get_company_name(self):
+        if self._is_company():
+            return self.partner_data.get("tradename") or self.partner_data.get("name")
+        else:
+            return None
+
     def _get_name(self):
-        if self.partner_data.get("party_type") == "organization":
+        if self._is_company():
             return self.partner_data.get("name")
         else:
             return " ".join(
